//
// See the file LICENSE for redistribution information.
//
// Copyright (c) 2002
//	Sleepycat Software.  All rights reserved.
//

#include "Portability.hpp"
#include <string>
#include <dbg.h>
#include "XmlException.hpp"
#include "DatabaseManager.hpp"
#include "FindMemoryLeaks.hpp"

using namespace Sleepycat;

static char THIS_FILE[] = __FILE__;

DatabaseManager::databaseDefinition DatabaseManager::databaseDefinitions[] =
{
	{ CONFIGURATION, Database::SECONDARY, false, "configuration" },
	{ DOCUMENT_PRIMARY, Database::PRIMARY, false, "document" },
	{ DOCUMENT_SECONDARY, Database::SECONDARY, true, "document" },
	{ DICTIONARY_PRIMARY, Database::PRIMARY, false, "dictionary" },
	{ DICTIONARY_SECONDARY, Database::SECONDARY, true, "dictionary" },
	{ DICTIONARY_STATISTICS, Database::SECONDARY, false, "statistics" }
};

DatabaseManager::DatabaseManager(DbEnv *environment, u_int32_t flags)
 : databases(SIZE),
 environment(environment),
 databaseCreationFlags(flags)
{
}

DatabaseManager::~DatabaseManager()
{
}

int DatabaseManager::open(DbTxn *txn, DatabaseId databaseid, const std::string& containername, u_int32_t flags, Database *&database)
{
	int err= 0;
	dbg::assertion(dbg::error, DBG_ASSERTION(databases[databaseid].get()==0));
	database = new Database(environment,databaseCreationFlags);
	err= database->open(
		txn,
		databaseDefinitions[databaseid].databaseType,
		databaseDefinitions[databaseid].duplicates,
		containername,
		databaseDefinitions[databaseid].databasename,
		flags);
	if(err==0)
	{
		databases[databaseid] = database;
	}
	else
	{
		database = NULL;
	}
	return err;
}

Database *DatabaseManager::get(DatabaseId databaseid) const
{
//	dbg::assertion(dbg::error, DBG_ASSERTION(databases[databaseid].get()!=0));
	return databases[databaseid];
}

